@@ -2,7 +2,7 @@ package AnyEvent::Twitter::Stream;
 
 use strict;
 use 5.008_001;
-our $VERSION = '0.17';
+our $VERSION = '0.18';
 
 use AnyEvent;
 use AnyEvent::HTTP;
@@ -36,6 +36,7 @@ sub new {
     my $token           = delete $args{token};
     my $token_secret    = delete $args{token_secret};
     my $method          = delete $args{method};
+    my $on_connect      = delete $args{on_connect} || sub { };
     my $on_tweet        = delete $args{on_tweet};
     my $on_error        = delete $args{on_error} || sub { die @_ };
     my $on_eof          = delete $args{on_eof} || sub { };
@@ -137,6 +138,8 @@ sub new {
             sub {
                 my ($handle, $headers) = @_;
 
+                $on_connect->();
+
                 if ($handle) {
                     $handle->on_error(sub {
                         undef $handle;
@@ -294,6 +297,10 @@ With this method you can specify what you want to filter amongst B<track>, B<fol
 
 Set the timeout value.
 
+=item B<on_connect>
+
+Callback to execute when a stream is connected.
+
 =item B<on_tweet>
 
 Callback to execute when a new tweet is received.
